[![PyPI version](https://badge.fury.io/py/sos-r.svg)](https://badge.fury.io/py/sos-r)
[![Build Status](https://travis-ci.org/vatlab/sos-r.svg?branch=master)](https://travis-ci.org/vatlab/sos-r)
[![Build status](https://ci.appveyor.com/api/projects/status/aa4cha4d57q7lhbq/branch/master?svg=true)](https://ci.appveyor.com/project/BoPeng/sos-r/branch/master)
[![Codacy Badge](https://api.codacy.com/project/badge/Grade/e7f047cd5fa545e585e134b62bad8aec)](https://www.codacy.com/app/BoPeng/sos-r?utm_source=github.com&amp;utm_medium=referral&amp;utm_content=vatlab/sos-r&amp;utm_campaign=Badge_Grade)
[![Coverage Status](https://coveralls.io/repos/github/vatlab/sos-r/badge.svg)](https://coveralls.io/github/vatlab/sos-r)

# sos-r
SoS extension for R. Please refer to [SoS Homepage](http://vatlab.github.io/SoS/) for details.
